@@ -4,6 +4,7 @@
 /* John Popplewell <john@johnnypops.demon.co.uk> */
 
 /* Sept. 30, 2002 - Oct. 1, 2002 */
+/* $Id: win32_print.h,v 1.7 2006/08/27 21:00:55 wkendrick Exp $ */
 
 
 #ifndef __WIN32_PRINT_H__
@@ -14,12 +15,12 @@
 #endif
 
 /* if printcfg is NULL, uses the default printer */
-extern const char *SurfacePrint( SDL_Surface *surf, 
-			         const char *printcfg, 
-			         int showdialog );
-extern int IsPrinterAvailable( void );
+extern const char *SurfacePrint(SDL_Surface * surf,
+				const char *printcfg, int showdialog);
+extern int IsPrinterAvailable(void);
 
 /* additional windows functions requiring <windows.h> */
 extern char *GetDefaultSaveDir(const char *suffix);
+extern char *GetSystemFontDir(void);
 
 #endif
